pywr.recorders.HydropowerRecorder
=================================

.. currentmodule:: pywr.recorders

.. autoclass:: HydropowerRecorder

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~HydropowerRecorder.after
      ~HydropowerRecorder.aggregated_value
      ~HydropowerRecorder.before
      ~HydropowerRecorder.finish
      ~HydropowerRecorder.load
      ~HydropowerRecorder.register
      ~HydropowerRecorder.reset
      ~HydropowerRecorder.setup
      ~HydropowerRecorder.to_dataframe
      ~HydropowerRecorder.unregister
      ~HydropowerRecorder.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~HydropowerRecorder.agg_func
      ~HydropowerRecorder.children
      ~HydropowerRecorder.comment
      ~HydropowerRecorder.data
      ~HydropowerRecorder.density
      ~HydropowerRecorder.efficiency
      ~HydropowerRecorder.energy_unit_conversion
      ~HydropowerRecorder.epsilon
      ~HydropowerRecorder.flow_unit_conversion
      ~HydropowerRecorder.ignore_nan
      ~HydropowerRecorder.is_constraint
      ~HydropowerRecorder.is_objective
      ~HydropowerRecorder.model
      ~HydropowerRecorder.name
      ~HydropowerRecorder.node
      ~HydropowerRecorder.parents
      ~HydropowerRecorder.temporal_agg_func
      ~HydropowerRecorder.turbine_elevation
      ~HydropowerRecorder.water_elevation_parameter
   
   